Crate bvs_vault_base

Re-exports

pub use crate::error::VaultError;

Modules

error
msg
Base messages required for all vaults.
offset
Virtual shares offset module for the vault to guard against inflation attacks.
proxy
Module for handling and approving proxy in the vault.
router
Base router (aka auth) module for the vault.
shares
Accounting module for vaults that tracks staker shares.